@@ -120,12 +120,19 @@ class ForumPost extends JTable
 	 */
 	var $hits       = NULL;
 
+	/**
+	 * varchar(100)
+	 * 
+	 * @var string
+	 */
+	var $scope = NULL;
+
 	/**
 	 * int(11)
 	 * 
 	 * @var integer
 	 */
-	var $group_id = NULL;
+	var $scope_id = NULL;
 
 	/**
 	 * tinyint(2)  0=public, 1=registered, 2=special, 3=protected, 4=private
@@ -155,6 +162,15 @@ class ForumPost extends JTable
 	 */
 	var $asset_id = NULL;
 
+	/**
+	 * int(11)
+	 * Used to associate another object such as a 
+	 * course lecture to a specific entry
+	 * 
+	 * @var integer
+	 */
+	var $object_id = NULL;
+
 	/**
 	 * Constructor
 	 *
@@ -237,6 +253,38 @@ class ForumPost extends JTable
 		}
 	}
 
+	/**
+	 * Load a record by its alias and bind data to $this
+	 * 
+	 * @param      string $oid Record alias
+	 * @return     boolean True upon success, False if errors
+	 */
+	public function loadByObject($oid=NULL, $scope_id=null, $scope='site')
+	{
+		if ($oid === NULL) 
+		{
+			return false;
+		}
+		$oid = intval($oid);
+
+		$query = "SELECT * FROM $this->_tbl WHERE object_id=" . $this->_db->Quote($oid);
+		if ($scope_id !== null)
+		{
+			$query .= " AND scope_id=" . $this->_db->Quote($scope_id) . " AND scope=" . $this->_db->Quote($scope) . " AND parent=0";
+		}
+
+		$this->_db->setQuery($query);
+		if ($result = $this->_db->loadAssoc()) 
+		{
+			return $this->bind($result);
+		} 
+		else 
+		{
+			$this->setError($this->_db->getErrorMsg());
+			return false;
+		}
+	}
+
 	/**
 	 * Validate data
 	 * 
@@ -262,6 +310,9 @@ class ForumPost extends JTable
 		}
 		$this->sticky = ($this->sticky) ? $this->sticky : 0;
 
+		$this->scope = preg_replace("/[^a-zA-Z0-9]/", '', strtolower($this->scope));
+		$this->scope_id = intval($this->scope_id);
+
 		$juser =& JFactory::getUser();
 		if (!$this->id) 
 		{
@@ -286,7 +337,10 @@ class ForumPost extends JTable
 	public function buildQuery($filters=array())
 	{
 		$query  = " FROM $this->_tbl AS c";
-		$query .= " LEFT JOIN #__xgroups AS g ON g.gidNumber=c.group_id";
+		if (isset($filters['group']) && (int) $filters['group'] >= 0) 
+		{
+			$query .= " LEFT JOIN #__xgroups AS g ON g.gidNumber=c.scope_id";
+		}
 		if (version_compare(JVERSION, '1.6', 'lt'))
 		{
 			$query .= " LEFT JOIN #__groups AS a ON c.access=a.id";
@@ -326,12 +380,24 @@ class ForumPost extends JTable
 			}
 			if (isset($filters['group']) && (int) $filters['group'] >= 0) 
 			{
-				$where[] = "c.group_id=" . $this->_db->Quote(intval($filters['group']));
+				$where[] = "(c.scope_id=" . $this->_db->Quote(intval($filters['group'])) . " AND c.scope=" . $this->_db->Quote('group') . ")";
+			}
+			if (isset($filters['scope']) && (string) $filters['scope']) 
+			{
+				$where[] = "c.scope=" . $this->_db->Quote(strtolower($filters['scope']));
+			}
+			if (isset($filters['scope_id']) && (int) $filters['scope_id'] >= 0) 
+			{
+				$where[] = "c.scope_id=" . $this->_db->Quote(intval($filters['scope_id']));
 			}
 			if (isset($filters['category_id']) && (int) $filters['category_id'] >= 0) 
 			{
 				$where[] = "c.category_id=" . $this->_db->Quote(intval($filters['category_id']));
 			}
+			if (isset($filters['object_id']) && (int) $filters['object_id'] >= 0) 
+			{
+				$where[] = "c.object_id=" . $this->_db->Quote(intval($filters['object_id']));
+			}
 			//if (!isset($filters['authorized']) || !$filters['authorized']) {
 			//	$query .= "c.access=0 AND ";
 			//}
@@ -398,7 +464,11 @@ class ForumPost extends JTable
 	 */
 	public function getRecords($filters=array())
 	{
-		$query = "SELECT c.*, g.cn AS group_alias";
+		$query = "SELECT c.*";
+		if (isset($filters['group']) && (int) $filters['group'] >= 0) 
+		{
+			$query .= ", g.cn AS group_alias";
+		}
 		if (!isset($filters['parent']) || $filters['parent'] == 0) 
 		{
 			$query .= ", (SELECT COUNT(*) FROM $this->_tbl AS r WHERE r.parent=c.id AND r.state<2) AS replies ";
@@ -466,7 +536,7 @@ class ForumPost extends JTable
 			return null;
 		}
 
-		$query = "SELECT r.* FROM $this->_tbl AS r WHERE r.parent=$parent ORDER BY created DESC LIMIT 1";
+		$query = "SELECT r.* FROM $this->_tbl AS r WHERE r.parent=" . $this->_db->Quote($parent) . " ORDER BY created DESC LIMIT 1";
 
 		$this->_db->setQuery($query);
 		$obj = $this->_db->loadObject();
@@ -484,17 +554,18 @@ class ForumPost extends JTable
 	 * @param      integer $category_id Category ID
 	 * @return     object
 	 */
-	public function getLastActivity($group_id=null, $category_id=null)
+	public function getLastActivity($scope_id=null, $scope='site', $category_id=null)
 	{
 		$query = "SELECT r.* FROM $this->_tbl AS r";
 		$where = array();
-		if ($group_id !== null)
+		if ($scope_id !== null)
 		{
-			$where[] = "r.group_id=$group_id";
+			$where[] = "r.scope_id=" . $this->_db->Quote($scope_id);
 		}
+		$where[] = "r.scope=" . $this->_db->Quote($scope);
 		if ($category_id !== null)
 		{
-			$where[] = "r.category_id=$category_id";
+			$where[] = "r.category_id=" . $this->_db->Quote($category_id);
 		}
 		if (count($where) > 0) 
 		{
@@ -528,7 +599,7 @@ class ForumPost extends JTable
 			return null;
 		}
 
-		$this->_db->setQuery("DELETE FROM $this->_tbl WHERE parent=$parent");
+		$this->_db->setQuery("DELETE FROM $this->_tbl WHERE parent=" . $this->_db->Quote($parent));
 		if (!$this->_db->query()) 
 		{
 			$this->setError($this->_db->getErrorMsg());
@@ -570,7 +641,7 @@ class ForumPost extends JTable
 		}
 		$values = implode(', ', $set);
 
-		$this->_db->setQuery("UPDATE $this->_tbl SET $values WHERE parent=$parent");
+		$this->_db->setQuery("UPDATE $this->_tbl SET $values WHERE parent=" . $this->_db->Quote($parent));
 		if (!$this->_db->query()) 
 		{
 			$this->setError($this->_db->getErrorMsg());
@@ -590,7 +661,7 @@ class ForumPost extends JTable
 	 * @param      integer $group_id Group ID
 	 * @return     boolean True on success
 	 */
-	public function updateCategory($old=null, $nw=null, $group_id=0)
+	public function updateCategory($old=null, $nw=null, $group_id=0, $scope='site')
 	{
 		if ($old === null) 
 		{
@@ -601,7 +672,7 @@ class ForumPost extends JTable
 			return false;
 		}
 
-		$this->_db->setQuery("UPDATE $this->_tbl SET category_id=$nw WHERE category_id=$old AND group_id=$group_id");
+		$this->_db->setQuery("UPDATE $this->_tbl SET category_id=" . $this->_db->Quote($nw) . " WHERE category_id=" . $this->_db->Quote($old) . " AND scope_id=" . $this->_db->Quote($scope_id) . " AND scope=" . $this->_db->Quote($scope));
 		if (!$this->_db->query()) 
 		{
 			$this->setError($this->_db->getErrorMsg());
@@ -695,7 +766,7 @@ class ForumPost extends JTable
 			$cat = intval($cat);
 		}
 		
-		$this->_db->setQuery("UPDATE $this->_tbl SET state=$state WHERE category_id IN ($cat)");
+		$this->_db->setQuery("UPDATE $this->_tbl SET state=" . $this->_db->Quote($state) . " WHERE category_id IN ($cat)");
 		if (!$this->_db->query()) 
 		{
 			$this->setError($this->_db->getErrorMsg());
