@@ -61,6 +61,7 @@ defined('_JEXEC') or die( 'Restricted access' );
 			<select name="year">
 <?php
 			$y = date("Y");
+			$year = $y;
 			$y++;
 			for ($i=2004, $n=$y; $i < $n; $i++)
 			{
@@ -100,8 +101,8 @@ defined('_JEXEC') or die( 'Restricted access' );
 		<tbody>
 			<tr>
 				<td><?php echo $this->opened['year']; ?></td>
-				<td><?php echo $this->opened['month']; ?></td>
-				<td><?php echo $this->opened['week']; ?></td>
+				<td><?php echo ($year == $this->year) ? $this->opened['month'] : '-'; ?></td>
+				<td><?php echo ($year == $this->year) ? $this->opened['week'] : '-'; ?></td>
 				<td class="major"><?php echo $this->opened['open']; ?></td>
 				<td class="critical"><?php echo $this->opened['unassigned']; ?></td>
 			</tr>
@@ -120,8 +121,8 @@ defined('_JEXEC') or die( 'Restricted access' );
 		<tbody>
 			<tr>
 				<td><?php echo $this->closed['year']; ?></td>
-				<td><?php echo $this->closed['month']; ?></td>
-				<td><?php echo $this->closed['week']; ?></td>
+				<td><?php echo ($year == $this->year) ? $this->closed['month'] : '-'; ?></td>
+				<td><?php echo ($year == $this->year) ? $this->closed['week'] : '-'; ?></td>
 				<td colspan="2" class="block"><?php echo (isset($this->lifetime[0])) ? $this->lifetime[0] : 0; ?> <span>days</span> <?php echo (isset($this->lifetime[1])) ? $this->lifetime[1] : 0; ?> <span>hours</span> <?php echo (isset($this->lifetime[2])) ? $this->lifetime[2] : 0; ?> <span>minutes</span></td>
 			</tr>
 		</tbody>
@@ -209,10 +210,10 @@ $max = ceil($number/10)*10;
 		<table class="support-stats-people" summary="Breakdown of people and the number of tickets closed">
 			<thead>
 				<tr>
-					<th scope="col"><a<?php if ($this->sort == 'name') { echo ' class="active"'; } ?> href="<?php echo JRoute::_('index.php?option='.$this->option.'&amp;task=stats&amp;type='.$type.'&amp;sort=name&amp;group='.$this->group.'&amp;year='.$this->year); ?>" title="Sort by name">&darr; Person</a></th>
-					<th scope="col"><a<?php if ($this->sort == 'year') { echo ' class="active"'; } ?> href="<?php echo JRoute::_('index.php?option='.$this->option.'&amp;task=stats&amp;type='.$type.'&amp;sort=year&amp;group='.$this->group.'&amp;year='.$this->year); ?>" title="Sort by year count">&darr; Closed this year</a></th>
-					<th scope="col"><a<?php if ($this->sort == 'month') { echo ' class="active"'; } ?> href="<?php echo JRoute::_('index.php?option='.$this->option.'&amp;task=stats&amp;type='.$type.'&amp;sort=month&amp;group='.$this->group.'&amp;year='.$this->year); ?>" title="Sort by month count">&darr; Closed this month</a></th>
-					<th scope="col"><a<?php if ($this->sort == 'week') { echo ' class="active"'; } ?> href="<?php echo JRoute::_('index.php?option='.$this->option.'&amp;task=stats&amp;type='.$type.'&amp;sort=week&amp;group='.$this->group.'&amp;year='.$this->year); ?>" title="Sort by week count">&darr; Closed this week</a></th>
+					<th scope="col"><a<?php if ($this->sort == 'name') { echo ' class="active"'; } ?> href="<?php echo JRoute::_('index.php?option='.$this->option.'&amp;task=stats&amp;type='.$this->type.'&amp;sort=name&amp;group='.$this->group.'&amp;year='.$this->year); ?>" title="Sort by name">&darr; Person</a></th>
+					<th scope="col"><a<?php if ($this->sort == 'year') { echo ' class="active"'; } ?> href="<?php echo JRoute::_('index.php?option='.$this->option.'&amp;task=stats&amp;type='.$this->type.'&amp;sort=year&amp;group='.$this->group.'&amp;year='.$this->year); ?>" title="Sort by year count">&darr; Closed this year</a></th>
+					<th scope="col"><a<?php if ($this->sort == 'month') { echo ' class="active"'; } ?> href="<?php echo JRoute::_('index.php?option='.$this->option.'&amp;task=stats&amp;type='.$this->type.'&amp;sort=month&amp;group='.$this->group.'&amp;year='.$this->year); ?>" title="Sort by month count">&darr; Closed this month</a></th>
+					<th scope="col"><a<?php if ($this->sort == 'week') { echo ' class="active"'; } ?> href="<?php echo JRoute::_('index.php?option='.$this->option.'&amp;task=stats&amp;type='.$this->type.'&amp;sort=week&amp;group='.$this->group.'&amp;year='.$this->year); ?>" title="Sort by week count">&darr; Closed this week</a></th>
 				</tr>
 			</thead>
 			<tbody>
@@ -226,8 +227,8 @@ if ($this->users) {
 				<tr class="<?php echo $cls; ?>">
 					<th scope="row"><?php echo stripslashes($user->name); ?></th>
 					<td class="group"><?php echo $user->closed['year']; ?></td>
-					<td><?php echo $user->closed['month']; ?></td>
-					<td class="group"><?php echo $user->closed['week']; ?></td>
+					<td><?php echo ($year == $this->year) ? $user->closed['month'] : '-'; ?></td>
+					<td class="group"><?php echo ($year == $this->year) ? $user->closed['week'] : '-'; ?></td>
 				</tr>
 <?php
 	}
