@@ -127,6 +127,9 @@ if (!$this->app->sess) {
 				<param name="Offer relogin" value="Yes" />
 				<param name="DisableSSL" value="No" />
 				<param name="Show controls" value="No" />
+				<?php if (!empty($this->output->showlocalcursor)) {?>
+				<param name="ShowLocalCursor" value="<?php echo $this->output->showlocalcursor; ?>" />
+				<?php } ?>
 				<param name="ENCODING" value="<?php echo $this->output->encoding; ?>" />
 				<p class="error">
 					In order to view an application, you must have Java installed and enabled. (<a href="/kb/misc/java">How do I do this?</a>)
@@ -335,4 +338,4 @@ if (!$this->app->sess) {
 <?php if ($this->config->get('access-manage-session')) { ?>
 	<p id="app-manager"><?php echo JText::sprintf('Administrator viewing <span class="username"><strong>username:</strong> %s</span>, <span class="ip"><strong>IP:</strong> %s</span>, <span class="sess"><strong>session:</strong> %s</span>', $this->app->username, $this->app->ip, $this->app->sess); ?></p>
 <?php } ?>
-</div><!-- / .main section #session-section -->
\ No newline at end of file
+</div><!-- / .main section #session-section -->
